@@ -1,7 +1,7 @@
 package LWP::UserAgent::ProgressAny;
 
-our $DATE = '2015-01-22'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2015-01-23'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
@@ -54,16 +54,19 @@ sub __add_handlers {
                 pos => $new_pos,
                 message => sub {
                     my @msg = (
-                        "Downloading ",
+                        "<elspan prio=2>Downloading </elspan>",
+
+                        "<elspan prio=3 truncate=middle>",
                         $resp->{_request}{_uri},
-                        " ",
+                        " </elspan>",
+
                         format_metric($new_pos),
                     );
                     if ($progress->target) {
                         push @msg, "/", format_metric($progress->target);
                     }
                     # XXX show speed
-                join "", @msg;
+                    join "", @msg;
                 },
             );
         }
@@ -96,7 +99,7 @@ LWP::UserAgent::ProgressAny - See progress for your LWP::UserAgent requests
 
 =head1 VERSION
 
-This document describes version 0.05 of LWP::UserAgent::ProgressAny (from Perl distribution LWP-UserAgent-ProgressAny), released on 2015-01-22.
+This document describes version 0.06 of LWP::UserAgent::ProgressAny (from Perl distribution LWP-UserAgent-ProgressAny), released on 2015-01-23.
 
 =head1 SYNOPSIS
 
